@@ -71,7 +71,6 @@ class Client(object):
         event_params = event_params or {}
         event_params = convert_dict_to_filum_event_format(event_params)
         context = context or {}
-        context = convert_dict_to_filum_event_format(context)
         require('user_id or anonymous_id', user_id or anonymous_id, ID_TYPES)
         if user_id is None and anonymous_id is None:
             raise ValueError("Either User ID or Anonymous ID must be set.")
@@ -110,13 +109,13 @@ class Client(object):
                       original_timestamp=original_timestamp, origin=origin)
 
     def track(self, user_id=None, event_name=None, event_params=None, context=None,
-              timestamp=None, original_timestamp=None, anonymous_id=None):
+              timestamp=None, original_timestamp=None, anonymous_id=None, origin=None):
         event_params = event_params or {}
         context = context or {}
         require('user_id or anonymous_id', user_id or anonymous_id, ID_TYPES)
         return self.eventify(user_id=user_id, event_name=event_name, event_type="track", event_params=event_params,
                       context=context, timestamp=timestamp, original_timestamp=original_timestamp,
-                      anonymous_id=anonymous_id)
+                      anonymous_id=anonymous_id, origin=origin)
 
     def _enqueue(self, msg):
         """Push a new `msg` onto the queue, return `(success, msg)`"""
@@ -136,7 +135,7 @@ class Client(object):
         require('timestamp', timestamp, datetime)
         require('original_timestamp', original_timestamp, datetime)
 
-        require('context', msg['context'], list)
+        require('context', msg['context'], dict)
 
         # add common
         timestamp = guess_timezone(timestamp)
@@ -147,20 +146,10 @@ class Client(object):
         msg['received_at'] = msg['received_at'].isoformat()
 
         msg['event_id'] = stringify_id(event_id)
-        library_name = {
-            'key': 'name',
-            'value': {
-                'string_value': 'filum-python-sdk'
-            }
-        }
-        library_version = {
-            'key': 'version',
-            'value': {
-                'string_value': VERSION
-            }
-        }
-        msg['context'].append(library_name)
-        msg['context'].append(library_version)
+
+        # handle Context to follow Filum Event Schema
+        _context = process_context_data(msg['context'])
+        msg['context'] = _context
 
         msg['user_id'] = stringify_id(msg.get('user_id', ''))
         msg['anonymous_id'] = stringify_id(msg.get('anonymous_id', ''))
@@ -231,7 +220,7 @@ def convert_dict_to_filum_event_format(event_params):
         new_item['key'] = k
         new_item['value'] = {}
         if isinstance(v, int):
-            new_item['value'].update({'int_value': v})
+            new_item['value'].update({'int_value': int(v)})
         elif isinstance(v, float):
             new_item['value'].update({'double_value': v})
         elif isinstance(v, datetime):
@@ -243,3 +232,41 @@ def convert_dict_to_filum_event_format(event_params):
                 new_item['value'].update({'string_value': str(v)})
         event_params_server_format.append(new_item)
     return event_params_server_format
+
+
+def process_context_data(context):
+    _context = dict()
+    _context['active'] = 0
+    _context['app'] = {}
+    if "campaign" in context:
+        _context['campaign'] = context['campaign']
+    else:
+        _context['campaign'] = {}
+
+    if "device" in context:
+        _context['device'] = context['device']
+    else:
+        _context['device'] = {}
+
+    _context['ip'] = ""
+    _context['library'] = {
+        'name': 'filum-python-sdk',
+        'version': VERSION
+    }
+    _context['locale'] = 'vi-VN'
+    _context['location'] = {}
+    _context['network'] = {}
+    _context['os'] = {}
+    if "page" in context:
+        _context['page'] = context['page']
+    else:
+        _context['page'] = {}
+
+    if "referrer" in context:
+        _context['referrer'] = context['referrer']
+    else:
+        _context['referrer'] = {}
+
+    _context['screen'] = {}
+    _context['user_agent'] = ''
+    return _context
